@@ -10,14 +10,14 @@ setSNPTable <-function(snpInfo,table='allchrpos',db='snplistdb') {
     }  
     
     field.types <- list(chr="TEXT",pos="INTEGER",rsid="TEXT")
-    if(suppressWarnings(isFile(snpInfo))){
+    if(suppressWarnings(isFile(snpInfo[1]))){ # Use of '[1]' prevents warning from multiple comparisons
         dbWriteTable(conn=conn, name=table, value=snpInfo, 
                      row.names=FALSE,header=FALSE,
                      field.types=field.types, sep ="\t")
     } 
     else {
         if ( !all( names(field.types) %in% names(snpInfo)) ) {
-            return(print("The column names should have 'chr','pos','rsid'."))
+            stop("The column names should have 'chr','pos','rsid'.")
         }
         dbWriteTable(conn,table,snpInfo,row.names=FALSE)
     }
